==> socnetv_2.1.orig.tar.gz: socnetv-2.1/src/webcrawlerdialog.h <==
/***************************************************************************
 SocNetV: Social Network Visualizer
 version: 2.1
 Written in Qt
 
                         webcrawlerdialog.h  -  description
                             -------------------
    copyright            : (C) 2005-2016 by Dimitris B. Kalamaras
    email                : dimitris.kalamaras@gmail.com
    website:             : http://dimitris.apeiro.gr
    project site         : http://socnetv.sourceforge.net

 ***************************************************************************/

/*******************************************************************************
*     This program is free software: you can redistribute it and/or modify     *
*     it under the terms of the GNU General Public License as published by     *
*     the Free Software Foundation, either version 3 of the License, or        *
*     (at your option) any later version.                                      *
*                                                                              *
*     This program is distributed in the hope that it will be useful,          *
*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
*     GNU General Public License for more details.                             *
*                                                                              *
*     You should have received a copy of the GNU General Public License        *
*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
********************************************************************************/

#ifndef WEBCRAWLERDIALOG_H
#define WEBCRAWLERDIALOG_H


#include <QDialog>

#include "ui_webcrawlerdialog.h"
 

class WebCrawlerDialog: public QDialog
{
	Q_OBJECT
public:
	WebCrawlerDialog (QWidget *parent = 0);
public slots:
    void checkErrors ();
	void gatherData ();
signals:
    void userChoices( QString, int, int, bool, bool);
    void webCrawlerDialogError(QString);
private:
	Ui::WebCrawlerDialog ui;

};



#endif

==> socnetv_2.2.orig.tar.gz: socnetv-2.2/src/webcrawlerdialog.h <==
/***************************************************************************
 SocNetV: Social Network Visualizer
 version: 2.2
 Written in Qt
 
                         webcrawlerdialog.h  -  description
                             -------------------
    copyright            : (C) 2005-2017 by Dimitris B. Kalamaras
    email                : dimitris.kalamaras@gmail.com
    website:             : http://dimitris.apeiro.gr
    project site         : http://socnetv.org

 ***************************************************************************/

/*******************************************************************************
*     This program is free software: you can redistribute it and/or modify     *
*     it under the terms of the GNU General Public License as published by     *
*     the Free Software Foundation, either version 3 of the License, or        *
*     (at your option) any later version.                                      *
*                                                                              *
*     This program is distributed in the hope that it will be useful,          *
*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
*     GNU General Public License for more details.                             *
*                                                                              *
*     You should have received a copy of the GNU General Public License        *
*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
********************************************************************************/

#ifndef WEBCRAWLERDIALOG_H
#define WEBCRAWLERDIALOG_H


#include <QDialog>

#include "ui_webcrawlerdialog.h"
 

class WebCrawlerDialog: public QDialog
{
	Q_OBJECT
public:
	WebCrawlerDialog (QWidget *parent = 0);
public slots:
    void checkErrors ();
	void gatherData ();
signals:
    void userChoices( QString, int, int, bool, bool);
    void webCrawlerDialogError(QString);
private:
	Ui::WebCrawlerDialog ui;

};



#endif
